Documentation Overview // Werkzeug Documentation

# Werkzeug

The Swiss Army Knife For Python Web Developers

## Documentation Overview

Welcome to the Werkzeug documentation.

### Reference

Documentation regarding the Werkzeug modules:

- Installing Werkzeug
- Important Terms — read this before reading the documentation
- Tutorial — getting started with Werkzeug
- Unicode — short introduction into unicode in python and how Werkzeug encodes and decodes data.
- Wrappers — request and response objects
- Routing System — a powerful URL dispatcher and builder
- Mini Templates — a minimal templating system
- Management Script Utilities — tools to write simple management scripts
- Test Utilities — unittest support tools
- HTTP Exceptions — exceptions for HTTP
- Utilities — useful classes and functions
- Context Locals — a WSGI centric version of thread.local.
- Debugging System — an interactive debugger.
- Serving Applications — serving WSGI applications.
- API Stability — API stability

### General Development Information

This part of the documentation mainly explains how to develop WSGI applications. This is also interesting if you don’t want to use Werkzeug but other WSGI utilities; the ideas are the same.

- How WSGI Works — short introduction to WSGI and Werkzeug.
- Organizing Code — gives you an idea how you can organize your code when using Werkzeug.
- Other Libraries — links to other libraries you can use with Werkzeug.
- Reusable Applications — how to develop modular applications with reusable bits.
- Deploying WSGI Applications — ready for production? This page covers all the details you have to know to deploy your application on various webservers.